@@ -169,6 +169,37 @@ int reg_close(reg_registry* reg, reg_error* errPtr) {
     }
 }
 
+/**
+ * Do some initial configuration of a registry object.
+ *
+ * @param [in] reg     the registry to configure
+ * @return             true if success; false if failure
+ */
+int reg_configure(reg_registry* reg) {
+    sqlite3_stmt* stmt = NULL;
+    int result = 0;
+#if SQLITE_VERSION_NUMBER >= 3022000
+    /* Ensure WAL files persist. */
+    int persist = 1;
+    sqlite3_file_control(reg->db, "registry", SQLITE_FCNTL_PERSIST_WAL, &persist);
+#endif
+    /* Turn on fullfsync. */
+    if (sqlite3_prepare_v2(reg->db, "PRAGMA fullfsync = 1", -1, &stmt, NULL) == SQLITE_OK) {
+        int r;
+        do {
+            sqlite3_step(stmt);
+            r = sqlite3_reset(stmt);
+            if (r == SQLITE_OK) {
+                result = 1;
+            }
+        } while (r == SQLITE_BUSY);
+    }
+    if (stmt) {
+        sqlite3_finalize(stmt);
+    }
+    return result;
+}
+
 /**
  * Attaches a registry database to the registry object. Prior to calling this,
  * the registry object is not actually connected to the registry. This function
@@ -474,6 +505,26 @@ int reg_vacuum(char *db_path) {
     return result;
 }
 
+/**
+ * Checkpoints a registry database if WAL mode is available.
+ *
+ * @param [in] reg     registry to checkpoint
+ * @param [out] errPtr on error, a description of the error that occurred
+ * @return             true if success; false if failure
+ */
+int reg_checkpoint(reg_registry* reg, reg_error* errPtr) {
+
+#if SQLITE_VERSION_NUMBER >= 3022000
+    if (sqlite3_db_readonly(reg->db, "registry") == 0
+            && sqlite3_wal_checkpoint_v2(reg->db, "registry",
+            SQLITE_CHECKPOINT_PASSIVE, NULL, NULL) != SQLITE_OK) {
+        reg_sqlite_error(reg->db, errPtr, NULL);
+        return 0;
+    }
+#endif
+    return 1;
+}
+
 /**
  * Functions for access to the metadata table
  */
